summaryrefslogtreecommitdiffstats
path: root/examples
diff options
context:
space:
mode:
Diffstat (limited to 'examples')
-rw-r--r--examples/example_dcopexport.py6
-rw-r--r--examples/example_dcopext.py6
-rw-r--r--examples/kurldemo.py6
-rw-r--r--examples/menudemo.py6
-rw-r--r--examples/mimetype.py6
-rw-r--r--examples/pyKHTMLPart.py8
-rw-r--r--examples/pytde-sampler/qt_widgets/CONTRIB2
-rwxr-xr-xexamples/pytde-sampler/runner.py8
-rwxr-xr-xexamples/pytde-sampler/sampler.py4
-rw-r--r--examples/uikmdi.py4
-rw-r--r--examples/uiqxembed.py4
-rw-r--r--examples/uisampler.py2
-rw-r--r--examples/xmlmenudemo.py6
13 files changed, 34 insertions, 34 deletions
diff --git a/examples/example_dcopexport.py b/examples/example_dcopexport.py
index 1df6318..6c9efdb 100644
--- a/examples/example_dcopexport.py
+++ b/examples/example_dcopexport.py
@@ -34,7 +34,7 @@ copyright holder.
# which was written by Torben Weis and Julian Rockey
import sys
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData
from dcopexport import DCOPExObj
from qt import TQString, TQStringList
@@ -109,9 +109,9 @@ aboutData = KAboutData ("testdcopexport", "petshop",\
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
-KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
+TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
app = TDEApplication ()
dcop = app.dcopClient ()
diff --git a/examples/example_dcopext.py b/examples/example_dcopext.py
index 05a906d..e206a21 100644
--- a/examples/example_dcopext.py
+++ b/examples/example_dcopext.py
@@ -30,7 +30,7 @@ copyright holder.
import sys, time
import dcop
import dcopext
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData
from qt import TQString, TQCString
@@ -61,9 +61,9 @@ aboutData = KAboutData ("testdcopext", "testdcopext",\
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
-KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
+TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
app = TDEApplication ()
dcop = app.dcopClient ()
diff --git a/examples/kurldemo.py b/examples/kurldemo.py
index 30f0bb2..0c03007 100644
--- a/examples/kurldemo.py
+++ b/examples/kurldemo.py
@@ -31,7 +31,7 @@ urls = ["http://slashdot.org", "http://www.kde.org", "http://www.riverbankcomput
import sys
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData, KURL
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData, KURL
from tdeui import KMainWindow, KEdit
class MainWin (KMainWindow):
@@ -88,9 +88,9 @@ aboutData = KAboutData ("", "",\
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
-KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
+TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
app = TDEApplication ()
mainWindow = MainWin (None, "main window")
diff --git a/examples/menudemo.py b/examples/menudemo.py
index 9ddac1b..f6426ce 100644
--- a/examples/menudemo.py
+++ b/examples/menudemo.py
@@ -43,7 +43,7 @@ import sys
from qt import TQPopupMenu, SIGNAL, TQLabel, TQIconSet
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData, i18n, KIcon, KIconLoader, KShortcut
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData, i18n, KIcon, KIconLoader, KShortcut
from tdeui import KMainWindow, KMessageBox, KStdAction, KAction, KToggleAction, KFontSizeAction, KFontAction, KRadioAction,\
KActionSeparator, KActionMenu, KWindowListMenu
@@ -281,9 +281,9 @@ aboutData = KAboutData ("", "",\
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
-KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
+TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
app = TDEApplication ()
mainWindow = MainWin (None, "main window")
diff --git a/examples/mimetype.py b/examples/mimetype.py
index 61d5545..fc85699 100644
--- a/examples/mimetype.py
+++ b/examples/mimetype.py
@@ -41,7 +41,7 @@ import sys
from qt import TQWidget, TQButtonGroup, TQt, TQLabel, TQListView, TQListViewItem
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData, KURL
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData, KURL
from tdeui import KMainWindow, KTabCtl, KListBox
from kio import KMimeType, KService, KServiceGroup, KServiceType, KTrader, KServiceTypeProfile, KServiceGroup
@@ -259,9 +259,9 @@ aboutData = KAboutData ("", "",\
version, description, KAboutData.License_GPL,\
"(C) 2003 Jim Bublitz")
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
-KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
+TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
app = TDEApplication ()
mainWindow = MainWin (None, "main window")
diff --git a/examples/pytde-sampler/qt_widgets/CONTRIB b/examples/pytde-sampler/qt_widgets/CONTRIB
index 3e0c57f..3c741aa 100644
--- a/examples/pytde-sampler/qt_widgets/CONTRIB
+++ b/examples/pytde-sampler/qt_widgets/CONTRIB
@@ -28,7 +28,7 @@ tdecore,KCalendarSystemFactory,,,
tdecore,KCatalogue,,,
tdecore,KCharsets,,,
tdecore,KClipboardSynchronizer,,,
-tdecore,KCmdLineArgs,,,
+tdecore,TDECmdLineArgs,,,
tdecore,KCmdLineOptions,,,
tdecore,KCodecs,,,
tdecore,KCompletion,,,
diff --git a/examples/pytde-sampler/runner.py b/examples/pytde-sampler/runner.py
index 3f479f6..d9eee11 100755
--- a/examples/pytde-sampler/runner.py
+++ b/examples/pytde-sampler/runner.py
@@ -3,7 +3,7 @@
"""
import sys
-from tdecore import TDEApplication, KCmdLineArgs
+from tdecore import TDEApplication, TDECmdLineArgs
from tdeui import KMainWindow
from qt import TQVBoxLayout
@@ -42,10 +42,10 @@ def importItem(name):
if __name__ == '__main__':
options = [('+item', 'An item in the sys.path')]
- KCmdLineArgs.init(sys.argv, about.about)
- KCmdLineArgs.addCmdLineOptions(options)
+ TDECmdLineArgs.init(sys.argv, about.about)
+ TDECmdLineArgs.addCmdLineOptions(options)
- args = KCmdLineArgs.parsedArgs()
+ args = TDECmdLineArgs.parsedArgs()
if not args.count():
args.usage()
else:
diff --git a/examples/pytde-sampler/sampler.py b/examples/pytde-sampler/sampler.py
index ec1d053..4e7eb43 100755
--- a/examples/pytde-sampler/sampler.py
+++ b/examples/pytde-sampler/sampler.py
@@ -14,7 +14,7 @@ from qt import SIGNAL, SLOT, PYSIGNAL, TQt
from qt import TQVBoxLayout, TQLabel, TQPixmap, TQSplitter, TQFrame, TQDialog
from qt import TQSizePolicy, TQHBoxLayout, TQSpacerItem, TQPushButton
-from tdecore import i18n, KAboutData, TDEApplication, KCmdLineArgs, KGlobal
+from tdecore import i18n, KAboutData, TDEApplication, TDECmdLineArgs, KGlobal
from tdecore import KGlobalSettings, KWin, KWinModule, KURL, KIcon
from tdeui import KComboBox, KListView, KListViewItem, KTabWidget, KTextEdit
@@ -409,7 +409,7 @@ class SamplerMainWindow(KMainWindow):
if __name__ == '__main__':
aboutdata = about.about()
- KCmdLineArgs.init(sys.argv, aboutdata)
+ TDECmdLineArgs.init(sys.argv, aboutdata)
app = TDEApplication()
splashpix = TQPixmap(os.path.join(lib.samplerpath, 'aboutkde.png'))
diff --git a/examples/uikmdi.py b/examples/uikmdi.py
index 1034232..32735ce 100644
--- a/examples/uikmdi.py
+++ b/examples/uikmdi.py
@@ -29,7 +29,7 @@ import os
import sys
from qt import SIGNAL, TQVBoxLayout, TQLabel
-from tdecore import i18n, KAboutData, TDEApplication, KGlobal, KIcon, KCmdLineArgs
+from tdecore import i18n, KAboutData, TDEApplication, KGlobal, KIcon, TDECmdLineArgs
from tdeui import KDockWidget, KListBox, KStdAction
try:
@@ -196,7 +196,7 @@ if __name__ == '__main__':
about = KAboutData(aname, aname, ver, desc, lic, '%s (c) 2004' % authormail)
about.addAuthor(author, 'hi, mom!', authormail)
about.addAuthor ('Jim Bublitz', 'For PyKDE', 'jbublitz@nwinternet.com')
- KCmdLineArgs.init(sys.argv, about)
+ TDECmdLineArgs.init(sys.argv, about)
app = TDEApplication()
mainWindow = KmdiExample()
mainWindow.show()
diff --git a/examples/uiqxembed.py b/examples/uiqxembed.py
index 382739d..a204d7a 100644
--- a/examples/uiqxembed.py
+++ b/examples/uiqxembed.py
@@ -6,7 +6,7 @@ import sys
from qt import TQIconSet, TQProcess, TQTimer, SIGNAL, SLOT
-from tdecore import KAboutData, TDEApplication, KCmdLineArgs, KGlobal, KIcon
+from tdecore import KAboutData, TDEApplication, TDECmdLineArgs, KGlobal, KIcon
from tdecore import KWin, KWinModule
from tdeui import KComboBox, KMainWindow, KPushButton, QXEmbed
@@ -111,7 +111,7 @@ if __name__ == '__main__':
about = KAboutData(aname, aname, ver, desc, lic, '%s (c) 2004' % authormail)
about.addAuthor(author, 'hi, mom!', authormail)
about.addAuthor ('Jim Bublitz', 'For PyKDE', 'jbublitz@nwinternet.com')
- KCmdLineArgs.init(sys.argv, about)
+ TDECmdLineArgs.init(sys.argv, about)
app = TDEApplication()
mainWindow = ExampleMain()
mainWindow.show()
diff --git a/examples/uisampler.py b/examples/uisampler.py
index 29a0f92..3a1b00c 100644
--- a/examples/uisampler.py
+++ b/examples/uisampler.py
@@ -3,7 +3,7 @@ sys.path.append ("./uimodules")
from qt import TQSplitter, TQWidgetStack, TQWidget, TQListViewItem, SIGNAL, TQCString , TQScrollView, TQRect, TQt
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData
from tdeui import KMainWindow, KListView
from uidialogs import *
diff --git a/examples/xmlmenudemo.py b/examples/xmlmenudemo.py
index f05d312..bc9a9a2 100644
--- a/examples/xmlmenudemo.py
+++ b/examples/xmlmenudemo.py
@@ -43,7 +43,7 @@ import sys, os
from qt import TQPopupMenu, SIGNAL, TQLabel, TQIconSet
-from tdecore import TDEApplication, KCmdLineArgs, KAboutData, i18n, KIcon, KIconLoader, KShortcut, KGlobal
+from tdecore import TDEApplication, TDECmdLineArgs, KAboutData, i18n, KIcon, KIconLoader, KShortcut, KGlobal
from tdeui import KMainWindow, KMessageBox, KStdAction, KAction, KToggleAction, KFontSizeAction, KFontAction, KRadioAction,\
KActionSeparator, KActionMenu, KWindowListMenu, KXMLGUIClient, KActionCollection
@@ -281,9 +281,9 @@ aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
aboutData.addAuthor ("author2", "they did something else", "another@email.address")
mainpath = os.path.dirname (os.path.abspath (sys.argv[0]))
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
-KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
+TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
app = TDEApplication ()
mainWindow = MainWin (None, "main window")
diff --git a/examples/pyKHTMLPart.py b/examples/pyKHTMLPart.py
index 6d92c1c..bcccdc7 100644
--- a/examples/pyKHTMLPart.py
+++ b/examples/pyKHTMLPart.py
@@ -43,7 +43,7 @@ lifted from the KDE classref.
# If you import more classes, don't forget to add them here (some of these
# are extras/not used)
-from tdecore import KCmdLineArgs, KURL, TDEApplication, i18n, KAboutData, BarIcon, KLibLoader
+from tdecore import TDECmdLineArgs, KURL, TDEApplication, i18n, KAboutData, BarIcon, KLibLoader
from tdeui import KMainWindow, KMessageBox, KAction, KStdAction, KKeyDialog, KEditToolbar
@@ -193,7 +193,7 @@ aboutData = KAboutData ("pyKHTMLPart", "pyHTMLPart",\
aboutData.addAuthor ("Jim Bublitz", "Example for PyKDE", "jbublitz@nwinternet.com")
# This MUST go here (before TDEApplication () is called)
-KCmdLineArgs.init (sys.argv, aboutData)
+TDECmdLineArgs.init (sys.argv, aboutData)
app = TDEApplication ()
@@ -205,10 +205,10 @@ else:
parts = pyPartsMW (None, "pyParts")
if len(sys.argv) > 1:
# read kcmdlineargs.h for the full unabridged instructions
# on using KCmdLineArgs, it's pretty confusing at first, but it works
# This is pretty useless in this program - you might want to
# expand this in your app (to load a file, etc)
- args = KCmdLineArgs.parsedArgs()
+ args = TDECmdLineArgs.parsedArgs()
parts.show()
app.exec_loop()
@@ -205,10 +205,10 @@ else:
if len(sys.argv) > 1:
# read kcmdlineargs.h for the full unabridged instructions
- # on using KCmdLineArgs, it's pretty confusing at first, but it works
+ # on using TDECmdLineArgs, it's pretty confusing at first, but it works
# This is pretty useless in this program - you might want to
# expand this in your app (to load a file, etc)